import java.awt.Color;
import java.awt.Container;
import java.awt.FlowLayout;

import javax.swing.JApplet;
import javax.swing.JButton;
import javax.swing.JFrame;

/**
 *  Class that demonstrates a GUI manager that can run as either
 *  an applet or a stand-alone application.
 *
 *  @author Nicholas R. Howe, modified by Sara Sheehan
 *  @version February 8, 2016
 */
public class BullsEyeGUI extends JApplet {
	
	/** For serializing the class (ignore for now) */
	private static final long serialVersionUID = 1L;
	
    /** The bullseye that will be displayed */
    private JBullsEye bullseye;

    /** Set up fields to default values */
    public BullsEyeGUI() {
    		Color colorArray[] = {Color.white, Color.black, Color.blue, 
    				Color.red, Color.yellow};
        this.bullseye = new JBullsEye(50,colorArray);
    }

    /** This method is called by the application version. */
    public void createAndShowGUI() {
        // Make sure we have nice window decorations.
        JFrame.setDefaultLookAndFeelDecorated(true);

        // Create and set up the window.
        JFrame frame = new JFrame("Sample GUI Application");
        try { 
        		frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
        } catch (Exception e) {}

        // Add components
        createComponents(frame.getContentPane());

        // Display the window.
        frame.pack();
        frame.setVisible(true);
    }

    /**
     *  Both types of app call this to set up the GUI contents.
     *  @param pane  The pane of the JFrame of JApplet
     */
    public void createComponents(Container pane) {
    		pane.setLayout(new FlowLayout());
    		pane.add(this.bullseye);
    		
    		JButton cycleButton = new JButton("Cycle");
    		pane.add(cycleButton);
    		
    		JButton invertButton = new JButton("Invert");
    		pane.add(invertButton);
    }

    /** This is the entry point for the applet version */
    public void init() {
    		//Execute a job on the event-dispatching thread:
    		//creating this applet's GUI.
    		try {
    			javax.swing.SwingUtilities.invokeAndWait(new Runnable() {
    				public void run() {
    					// line below would create separate window
    					//gui.createAndShowGUI();

    					// this line creates applet in browser window
    					createComponents(getContentPane());
    				}
    			});
    		} catch (Exception e) {
    			System.err.println("createGUI didn't successfully complete");
    		}
    }

    /** This is the entry point for the application version */
    public static void main(String[] args) {
        final BullsEyeGUI gui = new BullsEyeGUI();
        
        // Schedule a job for the event-dispatching thread:
        // creating and showing this application's GUI.
        javax.swing.SwingUtilities.invokeLater(new Runnable() {
        		public void run() {
        			gui.createAndShowGUI();
        		}
	    });
    }
}
